<?php
/**
 * Micologia che passione functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Micologia_che_passione
 */

 $theme = wp_get_theme();
 define( 'THEME_VERSION', $theme->version ); // gets version written in your style.css.

if ( ! function_exists( 'micologia_che_passione_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function micologia_che_passione_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Micologia che passione, use a find and replace
		 * to change 'micologia-che-passione' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'micologia-che-passione', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// This theme styles the visual editor with editor-style.css to match the theme style.
		add_editor_style();

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		* Enable support for custom-header.
		*/

		$args = array(
			'flex-width' => true,
			'default-image' => '',
		);
		add_theme_support( 'custom-header', $args );


		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// Thumbnail sizes.
		add_image_size( 'micologia-che-passione_single', 800, 999, false );
		add_image_size( 'micologia-che-passione_big', 1400, 928, true ); // (cropped)


		// This theme uses wp_nav_menu() in one location.
    function micologia_che_passione_menus() {
      $locations = array(
        'primary'  => __( 'Desktop Horizontal Menu', 'micologia-che-passione' ),
        'expanded' => __( 'Desktop Expanded Menu', 'micologia-che-passione' ),
        'mobile'   => __( 'Mobile Menu', 'micologia-che-passione' ),
        'footer'   => __( 'Footer Menu', 'micologia-che-passione' ),
        'social'   => __( 'Social Menu', 'micologia-che-passione' ),
      );

      register_nav_menus( $locations );
    }

    add_action( 'init', 'micologia_che_passione_menus' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		// Aggiungo dei colori da utilizzare con l'editor.
		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => __( 'White', 'micologia-che-passione' ),
					'slug'  => 'white',
					'color' => '#ffffff',
				),
				array(
					'name'  => __( 'Blanchedalmond', 'micologia-che-passione' ),
					'slug'  => 'blanchedalmond',
					'color' => '#ffeace',
				),
				array(
					'name'  => __( 'Navajowhite', 'micologia-che-passione' ),
					'slug'  => 'navajowhite',
					'color' => '#fcde9d',
				),
				array(
					'name'  => __( 'Crimson', 'micologia-che-passione' ),
					'slug'  => 'crimson',
					'color' => '#ad351c',
				),
				array(
					'name'  => __( 'Grey5 ', 'micologia-che-passione' ),
					'slug'  => 'grey5',
					'color' => '#161511',
				),
				array(
					'name'  => __( 'Black', 'micologia-che-passione' ),
					'slug'  => 'black',
					'color' => '#000000',
				),
			)
		);

		// Set up the WordPress core custom background feature.
		$defaults = array(
			'default-color' => '#ffffff',
			'default-image' => '',
		);
		add_theme_support( 'custom-background', $defaults );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Aggiunge il campo excerpt alle pagine.
		add_post_type_support( 'page', 'excerpt' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 100,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'micologia_che_passione_setup' );

/**
 * Dichiaro supporto per le funzionalità di Gutenberg.
 */
add_action( 'after_setup_theme', 'micologia_che_passione_add_gutenberg_support' );
/**
 * Funzione.
 */
function micologia_che_passione_add_gutenberg_support() {

	// Dichiaro supporto per allineamenti wide e full.
	add_theme_support( 'align-wide' );

}
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function micologia_che_passione_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'micologia_che_passione_content_width', 640 );
}
add_action( 'after_setup_theme', 'micologia_che_passione_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function micologia_che_passione_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'micologia-che-passione' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Add widgets here.', 'micologia-che-passione' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
    register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar-bottom', 'micologia-che-passione' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Add widgets here.', 'micologia-che-passione' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
        )
    );
}
add_action( 'widgets_init', 'micologia_che_passione_widgets_init' );

/**
 *  Enqueue css
 */
function micologia_che_passione_styles() {


	wp_enqueue_style( 'micologia-che-passione-font', 'https://fonts.googleapis.com/css?family=Heebo:400,900&display=swap', array(), '1.1', 'all' );
	wp_enqueue_style( 'micologia-che-passione-style', get_template_directory_uri() . '/style.css', [], THEME_VERSION, 'all' );
	wp_enqueue_style( 'micologia-che-passione-font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', [], THEME_VERSION, 'all' );

}

add_action( 'wp_enqueue_scripts', 'micologia_che_passione_styles' );

/**
 * Enqueue scripts.
 */
function micologia_che_passione_scripts() {

	wp_enqueue_script( 'micologia-che-passione-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
  wp_enqueue_script( 'micologia-che-passione-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), '1.0.0', true );
	wp_enqueue_script( 'micologia-che-passione-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
  wp_enqueue_script( 'micologia-che-passione-index', get_template_directory_uri() . '/js/index.js', array( 'jquery' ), '1.0.0', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'micologia_che_passione_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

require get_template_directory() . '/classes/class-svg-icons.php';
require get_template_directory() . '/inc/svg-icons.php';

// Custom page walker.
require get_template_directory() . '/classes/class-walker-page.php';
// Custom script loader class.

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
