<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Micologia_che_passione
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
	<div id="page" class="site">
		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'micologia-che-passione' ); ?></a>

		<header id="masthead" class="site-header">
			<div class="site-branding grid">
				<div class="col-50 text-left">
					<div class="logo" >
						<?php
						the_custom_logo();
						?>
					</div>
					<div class="titoli">
						<?php
						if ( is_front_page() && is_home() ) :
							?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php
							else :
								?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
							endif;
							$micologia_che_passione_description = get_bloginfo( 'description', 'display' );
							if ( $micologia_che_passione_description || is_customize_preview() ) :
								?>
								<p class="site-description"><?php echo $micologia_che_passione_description; /* WPCS: xss ok. */ ?></p>
							<?php endif; ?>
						</div><!-- .site-titoli -->
					</div><!-- .col-50 text-left -->
					<div class="col-50 text-right">
						<div class="social">
							<?php
							wp_nav_menu(
								array(
									'theme_location' => 'social',
									'menu_id'        => 'social-menu',
								)
							);
							?>
						</div>
						<?php
						get_search_form();
						?>
					</div><!-- .col-50 text-right -->
				</div><!-- .site-branding -->
				<div class="header-inner section-inner">
					<div class="header-titles-wrapper">
						<button class="toggle nav-toggle mobile-nav-toggle" data-toggle-target=".menu-modal"  data-toggle-body-class="showing-menu-modal" aria-expanded="false" data-set-focus=".close-nav-toggle">
							<span class="toggle-inner">
								<span class="toggle-icon">
									<?php micologia_che_passione_the_theme_svg( 'ellipsis' ); ?>
								</span>
								<span class="toggle-text"><?php _e( 'Menu', 'micologia-che-passione' ); ?></span>
							</span>
						</button><!-- .nav-toggle -->
					</div>
					<div class="header-navigation-wrapper">
						<?php
						if ( has_nav_menu( 'primary' ) || ! has_nav_menu( 'expanded' ) ) {
							?>
							<nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e( 'Horizontal', 'micologia-che-passione' ); ?>" role="navigation">
								<ul class="primary-menu reset-list-style">
									<?php
									if ( has_nav_menu( 'primary' ) ) {
										wp_nav_menu(
											array(
												'container'  => '',
												'items_wrap' => '%3$s',
												'theme_location' => 'primary',
											)
										);
									} elseif ( ! has_nav_menu( 'expanded' ) ) {
										wp_list_pages(
											array(
												'match_menu_classes' => true,
												'show_sub_menu_icons' => true,
												'title_li' => false,
												'walker'   => new Micologia_Che_Passione_Walker_Page(),
											)
										);
									}
									?>
								</ul>
							</nav><!-- .primary-menu-wrapper -->
							<?php
						}
						?>
						<div class="header-toggles hide-no-js">
							<?php
							if ( has_nav_menu( 'expanded' ) ) {
								?>
						<div class="toggle-wrapper nav-toggle-wrapper has-expanded-menu">

									<button class="toggle nav-toggle desktop-nav-toggle" data-toggle-target=".menu-modal" data-toggle-body-class="showing-menu-modal" aria-expanded="false" data-set-focus=".close-nav-toggle">
										<span class="toggle-inner">
											<span class="toggle-text"><?php _e( 'Menu', 'micologia-che-passione' ); ?></span>
											<span class="toggle-icon">
												<?php micologia_che_passione_the_theme_svg( 'ellipsis' ); ?>
											</span>
										</span>
									</button><!-- .nav-toggle -->
								</div><!-- .nav-toggle-wrapper -->
								<?php
							}
 							?>
						</div><!-- .header-toggles -->

					</div><!-- .header-navigation-wrapper -->
				</div><!-- .header-inner -->
			</header><!-- #masthead -->
			<?php
			// Output the menu modal.
			get_template_part( 'template-parts/modal-menu' );
      	get_sidebar();
      	?>
			<div class=cropped">
				<?php if ( get_header_image() ) : ?>
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php header_image(); ?>" class="cropped header-image" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" /></a>
					<?php endif; ?>
					</div>
					<div id="content" class="site-content grid">
